==> api-0.15.0-sources.jar: eu/fispace/api/ag/IrrigationAdviceResponse.java <==
//
// Este archivo ha sido generado por la arquitectura JavaTM para la implantación de la referencia de enlace (JAXB) XML v2.2.7 
// Visite <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
// Todas las modificaciones realizadas en este archivo se perderán si se vuelve a compilar el esquema de origen. 
// Generado el: 2015.07.15 a las 02:44:34 PM CEST 
//


package eu.fispace.api.ag;

import java.io.Serializable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import eu.limetri.ygg.api.ResponseMessage;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;


/**
 * <p>Clase Java para anonymous complex type.
 * 
 * <p>El siguiente fragmento de esquema especifica el contenido que se espera que haya en esta clase.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.limetri.eu/schemas/ygg}ResponseMessage">
 *       &lt;sequence>
 *         &lt;element name="latitude" type="{http://www.w3.org/2001/XMLSchema}double"/>
 *         &lt;element name="longitude" type="{http://www.w3.org/2001/XMLSchema}double"/>
 *         &lt;element name="isIrrigationNecessary" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="irrigationAmount" type="{http://www.w3.org/2001/XMLSchema}double" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "latitude",
    "longitude",
    "isIrrigationNecessary",
    "irrigationAmount"
})
@XmlRootElement(name = "IrrigationAdviceResponse")
public class IrrigationAdviceResponse
    extends ResponseMessage
    implements Serializable, ToString
{

    protected double latitude;
    protected double longitude;
    @XmlElement(required = true)
    protected String isIrrigationNecessary;
    protected Double irrigationAmount;

    /**
     * Obtiene el valor de la propiedad latitude.
     * 
     */
    public double getLatitude() {
        return latitude;
    }

    /**
     * Define el valor de la propiedad latitude.
     * 
     */
    public void setLatitude(double value) {
        this.latitude = value;
    }

    public boolean isSetLatitude() {
        return true;
    }

    /**
     * Obtiene el valor de la propiedad longitude.
     * 
     */
    public double getLongitude() {
        return longitude;
    }

    /**
     * Define el valor de la propiedad longitude.
     * 
     */
    public void setLongitude(double value) {
        this.longitude = value;
    }

    public boolean isSetLongitude() {
        return true;
    }

    /**
     * Obtiene el valor de la propiedad isIrrigationNecessary.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIsIrrigationNecessary() {
        return isIrrigationNecessary;
    }

    /**
     * Define el valor de la propiedad isIrrigationNecessary.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIsIrrigationNecessary(String value) {
        this.isIrrigationNecessary = value;
    }

    public boolean isSetIsIrrigationNecessary() {
        return (this.isIrrigationNecessary!= null);
    }

    /**
     * Obtiene el valor de la propiedad irrigationAmount.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getIrrigationAmount() {
        return irrigationAmount;
    }

    /**
     * Define el valor de la propiedad irrigationAmount.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setIrrigationAmount(Double value) {
        this.irrigationAmount = value;
    }

    public boolean isSetIrrigationAmount() {
        return (this.irrigationAmount!= null);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            double theLatitude;
            theLatitude = (this.isSetLatitude()?this.getLatitude(): 0.0D);
            strategy.appendField(locator, this, "latitude", buffer, theLatitude);
        }
        {
            double theLongitude;
            theLongitude = (this.isSetLongitude()?this.getLongitude(): 0.0D);
            strategy.appendField(locator, this, "longitude", buffer, theLongitude);
        }
        {
            String theIsIrrigationNecessary;
            theIsIrrigationNecessary = this.getIsIrrigationNecessary();
            strategy.appendField(locator, this, "isIrrigationNecessary", buffer, theIsIrrigationNecessary);
        }
        {
            Double theIrrigationAmount;
            theIrrigationAmount = this.getIrrigationAmount();
            strategy.appendField(locator, this, "irrigationAmount", buffer, theIrrigationAmount);
        }
        return buffer;
    }

    public IrrigationAdviceResponse withLatitude(double value) {
        setLatitude(value);
        return this;
    }

    public IrrigationAdviceResponse withLongitude(double value) {
        setLongitude(value);
        return this;
    }

    public IrrigationAdviceResponse withIsIrrigationNecessary(String value) {
        setIsIrrigationNecessary(value);
        return this;
    }

    public IrrigationAdviceResponse withIrrigationAmount(Double value) {
        setIrrigationAmount(value);
        return this;
    }

}

==> api-0.15.1-sources.jar: eu/fispace/api/ag/IrrigationAdviceResponse.java <==
//
// Este archivo ha sido generado por la arquitectura JavaTM para la implantación de la referencia de enlace (JAXB) XML v2.2.7 
// Visite <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
// Todas las modificaciones realizadas en este archivo se perderán si se vuelve a compilar el esquema de origen. 
// Generado el: 2015.08.07 a las 09:11:39 AM CEST 
//


package eu.fispace.api.ag;

import java.io.Serializable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import eu.limetri.ygg.api.ResponseMessage;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;


/**
 * <p>Clase Java para anonymous complex type.
 * 
 * <p>El siguiente fragmento de esquema especifica el contenido que se espera que haya en esta clase.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.limetri.eu/schemas/ygg}ResponseMessage">
 *       &lt;sequence>
 *         &lt;element name="latitude" type="{http://www.w3.org/2001/XMLSchema}double"/>
 *         &lt;element name="longitude" type="{http://www.w3.org/2001/XMLSchema}double"/>
 *         &lt;element name="isIrrigationNecessary" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="irrigationAmount" type="{http://www.w3.org/2001/XMLSchema}double" minOccurs="0"/>
 *         &lt;element name="additionalData" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "latitude",
    "longitude",
    "isIrrigationNecessary",
    "irrigationAmount",
    "additionalData"
})
@XmlRootElement(name = "IrrigationAdviceResponse")
public class IrrigationAdviceResponse
    extends ResponseMessage
    implements Serializable, ToString
{

    protected double latitude;
    protected double longitude;
    @XmlElement(required = true)
    protected String isIrrigationNecessary;
    protected Double irrigationAmount;
    protected String additionalData;

    /**
     * Obtiene el valor de la propiedad latitude.
     * 
     */
    public double getLatitude() {
        return latitude;
    }

    /**
     * Define el valor de la propiedad latitude.
     * 
     */
    public void setLatitude(double value) {
        this.latitude = value;
    }

    public boolean isSetLatitude() {
        return true;
    }

    /**
     * Obtiene el valor de la propiedad longitude.
     * 
     */
    public double getLongitude() {
        return longitude;
    }

    /**
     * Define el valor de la propiedad longitude.
     * 
     */
    public void setLongitude(double value) {
        this.longitude = value;
    }

    public boolean isSetLongitude() {
        return true;
    }

    /**
     * Obtiene el valor de la propiedad isIrrigationNecessary.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIsIrrigationNecessary() {
        return isIrrigationNecessary;
    }

    /**
     * Define el valor de la propiedad isIrrigationNecessary.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIsIrrigationNecessary(String value) {
        this.isIrrigationNecessary = value;
    }

    public boolean isSetIsIrrigationNecessary() {
        return (this.isIrrigationNecessary!= null);
    }

    /**
     * Obtiene el valor de la propiedad irrigationAmount.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getIrrigationAmount() {
        return irrigationAmount;
    }

    /**
     * Define el valor de la propiedad irrigationAmount.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setIrrigationAmount(Double value) {
        this.irrigationAmount = value;
    }

    public boolean isSetIrrigationAmount() {
        return (this.irrigationAmount!= null);
    }

    /**
     * Obtiene el valor de la propiedad additionalData.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAdditionalData() {
        return additionalData;
    }

    /**
     * Define el valor de la propiedad additionalData.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAdditionalData(String value) {
        this.additionalData = value;
    }

    public boolean isSetAdditionalData() {
        return (this.additionalData!= null);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            double theLatitude;
            theLatitude = (this.isSetLatitude()?this.getLatitude(): 0.0D);
            strategy.appendField(locator, this, "latitude", buffer, theLatitude);
        }
        {
            double theLongitude;
            theLongitude = (this.isSetLongitude()?this.getLongitude(): 0.0D);
            strategy.appendField(locator, this, "longitude", buffer, theLongitude);
        }
        {
            String theIsIrrigationNecessary;
            theIsIrrigationNecessary = this.getIsIrrigationNecessary();
            strategy.appendField(locator, this, "isIrrigationNecessary", buffer, theIsIrrigationNecessary);
        }
        {
            Double theIrrigationAmount;
            theIrrigationAmount = this.getIrrigationAmount();
            strategy.appendField(locator, this, "irrigationAmount", buffer, theIrrigationAmount);
        }
        {
            String theAdditionalData;
            theAdditionalData = this.getAdditionalData();
            strategy.appendField(locator, this, "additionalData", buffer, theAdditionalData);
        }
        return buffer;
    }

    public IrrigationAdviceResponse withLatitude(double value) {
        setLatitude(value);
        return this;
    }

    public IrrigationAdviceResponse withLongitude(double value) {
        setLongitude(value);
        return this;
    }

    public IrrigationAdviceResponse withIsIrrigationNecessary(String value) {
        setIsIrrigationNecessary(value);
        return this;
    }

    public IrrigationAdviceResponse withIrrigationAmount(Double value) {
        setIrrigationAmount(value);
        return this;
    }

    public IrrigationAdviceResponse withAdditionalData(String value) {
        setAdditionalData(value);
        return this;
    }

}
